@@ -16,6 +16,8 @@ import black
 import isort
 import libcst
 import pyupgrade._main
+from black.mode import TargetVersion
+from black.parsing import lib2to3_parse
 from pybetter.cli import (
     ALL_IMPROVEMENTS,
     FixMissingAllAttribute,
@@ -51,13 +53,13 @@ if sys.version_info[:2] >= (3, 8):  # pragma: no cover
     from com2ann import com2ann
 
 
-__version__ = "0.3.4"
+__version__ = "0.3.8"
 __all__ = ["shed", "docshed"]
 
 _version_map = {
     k: (int(k.name[2]), int(k.name[3:]))
-    for k in black.TargetVersion
-    if k.value >= black.TargetVersion.PY36.value
+    for k in TargetVersion
+    if k.value >= TargetVersion.PY36.value
 }
 _pybetter_fixers = tuple(
     fix().improve
@@ -80,13 +82,16 @@ def shed(
     assert all(isinstance(name, str) for name in first_party_imports)
     assert all(name.isidentifier() for name in first_party_imports)
 
+    if source_code == "":
+        return ""
+
     # Use black to autodetect our target versions
     target_versions = {
         v
         for v in black.detect_target_versions(
-            black.lib2to3_parse(source_code.lstrip(), set(_version_map))
+            lib2to3_parse(source_code.lstrip(), set(_version_map))
         )
-        if v.value >= black.TargetVersion.PY36.value
+        if v.value >= TargetVersion.PY36.value
     }
     assert target_versions
     min_version = _version_map[min(target_versions, key=attrgetter("value"))]
@@ -111,12 +116,12 @@ def shed(
             try:
                 # Might raise e.g. https://github.com/Instagram/LibCST/issues/446
                 newtree = fixer(tree)
-                # Catches e.g. https://github.com/lensvol/pybetter/issues/60
-                compile(newtree.code, "<string>", "exec")
             except Exception:
                 pass
             else:
                 tree = newtree
+                # Catches e.g. https://github.com/lensvol/pybetter/issues/60
+                compile(newtree.code, "<string>", "exec")
         source_code = tree.code
     # Then shed.docshed (below) formats any code blocks in documentation
     source_code = docshed(source=source_code, first_party_imports=first_party_imports)
@@ -127,14 +132,14 @@ def shed(
         source_code, settings=pyupgrade._main.Settings(min_version=pyupgrade_min)
     )
     source_code = pyupgrade._main._fix_tokens(source_code, min_version=pyupgrade_min)
-    source_code = pyupgrade._main._fix_py36_plus(source_code)
+    source_code = pyupgrade._main._fix_py36_plus(source_code, min_version=pyupgrade_min)
 
     # One tricky thing: running `isort` or `autoflake` can "unlock" further fixes
     # for `black`, e.g. "pass;#" -> "pass\n#\n" -> "#\n".  We therefore loop until
     # neither of them have made a change in the last loop body, trusting that
     # `black` itself is idempotent because that's tested upstream.
     prev = ""
-    black_mode = black.FileMode(target_versions=target_versions)
+    black_mode = black.Mode(target_versions=target_versions)  # type: ignore
     while prev != source_code:
         prev = source_code = black.format_str(source_code, mode=black_mode)
         source_code = autoflake.fix_code(
@@ -144,7 +149,7 @@ def shed(
             remove_duplicate_keys=True,
             remove_unused_variables=True,
         )
-        source_code = isort.code(  # type: ignore
+        source_code = isort.code(
             source_code,
             known_first_party=first_party_imports,
             known_local_folder={"tests"},
